<?php

/************************************************************/
/*                                                          */
/*   Flickr Widget                                        */
/*                                                          */
/************************************************************/
class App_Flickr extends WP_Widget {

    function __construct() {
        $widget_ops = array('description' => 'Flickr, Add Flickr phot stream box' );
        parent::__construct(false, __(wp_get_theme()->name.' - Flickr Photo Stream', 'tkingdom'),$widget_ops);
    }

    function widget( $args, $instance ) {
        extract( $args );

        $cur_arg = array(
            'title'     => $instance['title'],
            'type'      => empty( $instance['type'] ) ? 'user' : $instance['type'],
            'flickr_id' => $instance['flickr_id'],
            'count'     => (int) $instance['count'],
            'display'   => empty( $instance['display'] ) ? 'latest' : $instance['display'],
            'size'      => 's',
        );

        extract($cur_arg);

        echo $before_widget;

        if($title)
            echo $before_title . $title . $after_title;

        echo "<div class='tk-flickr-wrap'>";

        //If the widget have an ID, we can continue
        if(!empty( $instance['flickr_id'])){
            if (false === ($value = get_transient( 'cache_flick_box'))) {
                $flickr_box = "<script type='text/javascript' src='http://www.flickr.com/badge_code_v2.gne?count=$count&amp;display=$display&amp;size=$size&amp;layout=x&amp;source=$type&amp;$type=$flickr_id'></script>";
                set_transient( 'cache_flick_box', $flickr_box, 60 * 60 * 2);
            }
            echo get_transient('cache_flick_box');

        }else{
            echo '<p>'.__('Please provide an Flickr ID', 'tkingdom').'</p>';
        }
        echo '</div>';

        echo $after_widget;
    }


    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['type']       = strip_tags($new_instance['type']);
        $instance['flickr_id']  = strip_tags($new_instance['flickr_id']);
        $instance['count']      = (int) $new_instance['count'];
        $instance['display']    = strip_tags($new_instance['display']);
        $instance['title']      = strip_tags($new_instance['title']);

        return $instance;
    }


        function form($instance) {
        // Set up the default form values.
        $defaults = array(
            'title'      => esc_attr__( 'Flickr Widget', 'tkingdom' ),
            'type'       => 'user',
            'flickr_id'  => '', // 71865026@N00
            'count'      => 9,
            'display'    => 'display',
            'size'       => 's'
        );

        /* Merge the user-selected arguments with the defaults. */
        $instance = wp_parse_args( (array) $instance, $defaults );

        $types = array(
            'user'  => esc_attr__('user', 'tkingdom'),
            'group' => esc_attr__('group', 'tkingdom')
        );
        $displays = array(
            'latest' => esc_attr__('latest', 'tkingdom'),
            'random' => esc_attr__('random', 'tkingdom')
        );

        ?>

        <div>
            <p>
                <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'tkingdom'); ?></label><br />
                <small><?php _e( 'Give the widget title, or leave it empty for no title.', 'tkingdom' ); ?></small>
                <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />
            </p>
            <p>
                <label for="<?php echo $this->get_field_id('type'); ?>"><?php _e( 'Type', 'tkingdom' ); ?></label><br />
                <small><?php _e( 'The type of images from user or group.', 'tkingdom' ); ?></small>
                <select id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>">
                    <?php foreach ( $types as $k => $v ) { ?>
                        <option value="<?php echo esc_attr( $k ); ?>" <?php selected( $instance['type'], $k ); ?>><?php echo esc_html( $v ); ?></option>
                    <?php } ?>
                </select>
            </p>
            <p>
                <label for="<?php echo $this->get_field_id('flickr_id'); ?>"><?php _e('Flickr ID', 'tkingdom'); ?></label>
                <input id="<?php echo $this->get_field_id('flickr_id'); ?>" name="<?php echo $this->get_field_name('flickr_id'); ?>" type="text" value="<?php echo esc_attr( $instance['flickr_id'] ); ?>" /><br />
                <small><?php _e( 'Put the flickr ID here, go to <a href="http://goo.gl/PM6rZ" target="_blank">Flickr NSID Lookup</a> if you don\'t know your ID. Example: 71865026@N00', 'tkingdom' ); ?></small>
            </p>
            <p>
                <label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('Number', 'tkingdom'); ?></label><br />
                <small><?php _e( 'Number of images shown from 1 to 10', 'tkingdom' ); ?></small>
                <input class="column-last" id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>" type="text" value="<?php echo esc_attr( $instance['count'] ); ?>" size="3" />
            </p>
            <p>
                <label for="<?php echo $this->get_field_id('display'); ?>"><?php _e('Display Method', 'tkingdom'); ?></label><br />
                <small><?php _e( 'Get the image from recent or use random function.', 'tkingdom' ); ?></small>
                <select id="<?php echo $this->get_field_id( 'display' ); ?>" name="<?php echo $this->get_field_name( 'display' ); ?>">
                    <?php foreach ( $displays as $k => $v ) { ?>
                        <option value="<?php echo esc_attr( $k ); ?>" <?php selected( $instance['display'], $k ); ?>><?php echo esc_html( $v ); ?></option>
                    <?php } ?>
                </select>
            </p>
        </div>

        <?php
    }



}
register_widget('App_Flickr');
